@@ -16,7 +16,7 @@
 #' @param transport_mode character, set the transport mode: \code{"car"}, \code{"pedestrian"} or \code{"truck"}.
 #' @param traffic boolean, use real-time traffic or prediction in routing (\code{default = TRUE})? If no traffic is selected, the \code{datetime} is set to \code{"any"} and the request is processed independently from time.
 #' @param optimize, character, specifies how isoline calculation is optimized: \code{"balanced"}, \code{"quality"} or \code{"performance"} (\code{default = "balanced"}).
-#' @param consumption_model character, specify the consumption model of the vehicle, see \href{https://developer.here.com/documentation/routing-api/dev_guide/topics/use-cases/consumption-model.html}{consumption model} for more information (\code{default = NULL} a average electric car is set).
+#' @param consumption_model character, specify the consumption model of the vehicle (\code{default = NULL} an average electric car is set).
 #' @param aggregate boolean, aggregate (with function \code{min}) and intersect the isolines from geometry type \code{POLYGON} to geometry type \code{MULTIPOLYGON} (\code{default = TRUE})?
 #' @param url_only boolean, only return the generated URLs (\code{default = FALSE})?
 #'
@@ -85,8 +85,7 @@ isoline <- function(poi, datetime = Sys.time(), arrival = FALSE,
   } else {
     url <- paste0(
       url,
-      "&arrivalTime=any",
-      "&departureTime=any"
+      ifelse(arrival, "&arrivalTime=any", "&departureTime=any")
     )
   }
 
