@@ -19,7 +19,7 @@
 #' @param traffic boolean, use real-time traffic or prediction in routing (\code{default = TRUE})? If no traffic is selected, the \code{datetime} is set to \code{"any"} and the request is processed independently from time.
 #' @param avoid_area, \code{sf} object, area (only bounding box is taken) to avoid in routes (\code{default = NULL}).
 #' @param avoid_feature character, transport network features to avoid, e.g. \code{"tollRoad"} or \code{"ferry"} (\code{default = NULL}).
-#' @param consumption_model character, specify the consumption model of the vehicle, see \href{https://developer.here.com/documentation/routing-api/dev_guide/topics/use-cases/consumption-model.html}{consumption model} for more information (\code{default = NULL} a average electric car is set).
+#' @param consumption_model character, specify the consumption model of the vehicle (\code{default = NULL} an average electric car is set).
 #' @param url_only boolean, only return the generated URLs (\code{default = FALSE})?
 #'
 #' @return
@@ -61,12 +61,6 @@ route <- function(origin, destination, datetime = Sys.time(), arrival = FALSE,
   .check_character(avoid_feature)
   .check_boolean(url_only)
 
-  # Arrival time is not yet supported by the API
-  if (arrival) {
-    message("Arrival time is not supported at the moment on this endpoint (v8.16.0), please set 'arrival = FALSE'.")
-    return(NULL)
-  }
-
   # Add API key
   url <- .add_key(
     url = "https://router.hereapi.com/v8/routes?"
